@@ -6,7 +6,7 @@ mm.requireAs('ctypes', 'os','gc', np = 'numpy', plt = 'matplotlib.pyplot', globs
 import ctypes, os, gc
 import numpy as np
 import matplotlib.pyplot as plt
-from .C_ext import c_import
+from .C_ext import internal_Library
 
 class IsingModelSingle:
     '''class for 2D square lattice ising model simulator (only one size).
@@ -19,7 +19,7 @@ class IsingModelSingle:
     algorithm : `str`
         specifying Monte Carlo algorithm. 'wolff' and 'metropolis' can be captured. Default is 'metropolis'
     '''
-    _cdll = c_import('isingmonte')
+    _cdll = internal_Library('isingmonte')
     metropolis = _cdll.monteCarlo
     metropolis.argtypes = [np.ctypeslib.ndpointer(dtype=np.int32),
                  np.ctypeslib.ndpointer(dtype=np.int32),
